Master:
  .. image:: https://travis-ci.org/unfoldingWord-dev/python-gitea-client.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/unfoldingWord-dev/python-gitea-client
  .. image:: https://coveralls.io/repos/github/unfoldingWord-dev/python-gitea-client/badge.svg?branch=master
    :alt: Coverage
    :target: https://coveralls.io/github/unfoldingWord-dev/python-gitea-client?branch=master

Develop:
  .. image:: https://travis-ci.org/unfoldingWord-dev/python-gitea-client.svg?branch=develop
    :alt: Build Status
    :target: https://travis-ci.org/unfoldingWord-dev/python-gitea-client
  .. image:: https://coveralls.io/repos/github/unfoldingWord-dev/python-gitea-client/badge.svg?branch=develop
    :alt: Coverage
    :target: https://coveralls.io/github/unfoldingWord-dev/python-gitea-client?branch=develop


python-gitea-client
===================

This is a Python client to Gitea servers. The easiest way to install is via ``pip``::

    $ pip install gitea_client

Documentation for the module can be found `here <http://pythonhosted.org/gitea-client/>`_.
